@@ -67,7 +67,7 @@ class RoutingTree:
                 )
                 + ".slin"
             )
-            if os.path.isfile(ringback_path):
+            if RoutingTree.ringback_exists(ringback_path):
                 if self.routing_result.is_simple:
                     # we need to convert routing result into a simple fork
                     self.routing_result = IntermediateRoutingResult(
@@ -85,6 +85,10 @@ class RoutingTree:
                         0, self._make_ringback_target(ringback_path)
                     )
 
+    @staticmethod
+    def ringback_exists(ringback_path):
+        return os.path.isfile(ringback_path)
+
     def _populate_parameters_global(self, parameters):
         self.routing_result.target.parameters.update(parameters)
         for entry in self.new_routing_cache_content.values():
